==> policy-management-domain-1.0.20-sources.jar: com/xforceplus/ultraman/app/policymanagement/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.policymanagement.metadata;

/**
 *
 * @author ultraman
 * @since 2024-12-04
 */

public class PageMeta {
    public interface Zhangwuguanli {
        static String code() {
            return "zhangwuguanli";
        }
        static String name() {
            return "账务管理";
        }
    }
    public interface Jiageguanli {
        static String code() {
            return "jiageguanli";
        }
        static String name() {
            return "价格管理";
        }
    }
    public interface Accountingpolicy {
        static String code() {
            return "accountingpolicy";
        }
        static String name() {
            return "核算策略";
        }
    }
    public interface ExpenseInvoiceSettlement {
        static String code() {
            return "expenseInvoiceSettlement";
        }
        static String name() {
            return "费用项票结";
        }
    }
    public interface AfterSaleCheckHistory {
        static String code() {
            return "afterSaleCheckHistory";
        }
        static String name() {
            return "售后单对账履历";
        }
    }
    public interface SalesOrderCheckHistory {
        static String code() {
            return "salesOrderCheckHistory";
        }
        static String name() {
            return "销售单对账履历";
        }
    }
    public interface KsCheck {
        static String code() {
            return "ksCheck";
        }
        static String name() {
            return "快手账单";
        }
    }
    public interface TbCheck {
        static String code() {
            return "tbCheck";
        }
        static String name() {
            return "天猫账单";
        }
    }
    public interface WriteOffResult {
        static String code() {
            return "writeOffResult";
        }
        static String name() {
            return "应收回款核销";
        }
    }
    public interface PddSalesorder {
        static String code() {
            return "pddSalesorder";
        }
        static String name() {
            return "拼多多订单";
        }
    }
    public interface PolicyManagement {
        static String code() {
            return "policyManagement";
        }
        static String name() {
            return "策略管理";
        }
    }
    public interface SyncOrders {
        static String code() {
            return "syncOrders";
        }
        static String name() {
            return "同步电商订单";
        }
    }
    public interface PlatformSubsidyInvoiceSettlement {
        static String code() {
            return "platformSubsidyInvoiceSettlement";
        }
        static String name() {
            return "平台补贴票结";
        }
    }
    public interface CheckConfig {
        static String code() {
            return "checkConfig";
        }
        static String name() {
            return "对账策略配置";
        }
    }
    public interface WriteOffResultHistory {
        static String code() {
            return "writeOffResultHistory";
        }
        static String name() {
            return "应收回款核销履历";
        }
    }
    public interface OmsSalesorder {
        static String code() {
            return "omsSalesorder";
        }
        static String name() {
            return "网店管家OMS订单";
        }
    }
    public interface PddCheck {
        static String code() {
            return "pddCheck";
        }
        static String name() {
            return "拼多多账单";
        }
    }
    public interface JdSalesorder {
        static String code() {
            return "jdSalesorder";
        }
        static String name() {
            return "京东订单";
        }
    }
    public interface ReceivableStatistics {
        static String code() {
            return "receivableStatistics";
        }
        static String name() {
            return "应收汇总";
        }
    }
    public interface KsSalesorder {
        static String code() {
            return "ksSalesorder";
        }
        static String name() {
            return "快手订单";
        }
    }
    public interface ReceivableCheckHistory {
        static String code() {
            return "receivableCheckHistory";
        }
        static String name() {
            return "应收对账履历";
        }
    }
    public interface HistoryVersion {
        static String code() {
            return "historyVersion";
        }
        static String name() {
            return "版本履历";
        }
    }
    public interface WriteOffResultSnapshot {
        static String code() {
            return "writeOffResultSnapshot";
        }
        static String name() {
            return "月度核销明细快照表";
        }
    }
    public interface JkyOmsOrder {
        static String code() {
            return "jkyOmsOrder";
        }
        static String name() {
            return "吉客云OMS订单";
        }
    }
    public interface TbSalesorder {
        static String code() {
            return "tbSalesorder";
        }
        static String name() {
            return "天猫订单";
        }
    }
    public interface ReceivableCheckResult {
        static String code() {
            return "receivableCheckResult";
        }
        static String name() {
            return "应收对账";
        }
    }
    public interface DyCheck {
        static String code() {
            return "dyCheck";
        }
        static String name() {
            return "抖音账单";
        }
    }
    public interface ReceivableSalesOrder {
        static String code() {
            return "receivableSalesOrder";
        }
        static String name() {
            return "应收订单";
        }
    }
    public interface CollectionOrder {
        static String code() {
            return "collectionOrder";
        }
        static String name() {
            return "收款单";
        }
    }
    public interface DySalesorder {
        static String code() {
            return "dySalesorder";
        }
        static String name() {
            return "抖音订单";
        }
    }
    public interface JdCheck {
        static String code() {
            return "jdCheck";
        }
        static String name() {
            return "京东账单";
        }
    }
    public interface CollectionSummary {
        static String code() {
            return "collectionSummary";
        }
        static String name() {
            return "收款汇总单";
        }
    }
    public interface SalesOrderCheckResult {
        static String code() {
            return "salesOrderCheckResult";
        }
        static String name() {
            return "订单对账";
        }
    }
}

==> policy-management-domain-1.0.87-sources.jar: com/xforceplus/ultraman/app/policymanagement/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.policymanagement.metadata;

/**
 *
 * @author ultraman
 * @since 2024-12-16
 */

public class PageMeta {
    public interface Zhangwuguanli {
        static String code() {
            return "zhangwuguanli";
        }
        static String name() {
            return "账务管理";
        }
    }
    public interface Jiageguanli {
        static String code() {
            return "jiageguanli";
        }
        static String name() {
            return "价格管理";
        }
    }
    public interface Accountingpolicy {
        static String code() {
            return "accountingpolicy";
        }
        static String name() {
            return "核算策略";
        }
    }
    public interface AfterSaleCheckHistory {
        static String code() {
            return "afterSaleCheckHistory";
        }
        static String name() {
            return "售后单对账履历";
        }
    }
    public interface SalesOrderCheckHistory {
        static String code() {
            return "salesOrderCheckHistory";
        }
        static String name() {
            return "销售单对账履历";
        }
    }
    public interface PddSalesorder {
        static String code() {
            return "pddSalesorder";
        }
        static String name() {
            return "拼多多订单";
        }
    }
    public interface KsCheck {
        static String code() {
            return "ksCheck";
        }
        static String name() {
            return "快手账单";
        }
    }
    public interface TbCheck {
        static String code() {
            return "tbCheck";
        }
        static String name() {
            return "天猫账单";
        }
    }
    public interface WriteOffResult {
        static String code() {
            return "writeOffResult";
        }
        static String name() {
            return "应收回款核销";
        }
    }
    public interface InvoiceSettlementSubmitSummary {
        static String code() {
            return "invoiceSettlementSubmitSummary";
        }
        static String name() {
            return "票结提交汇总";
        }
    }
    public interface PolicyManagement {
        static String code() {
            return "policyManagement";
        }
        static String name() {
            return "策略管理";
        }
    }
    public interface SyncOrders {
        static String code() {
            return "syncOrders";
        }
        static String name() {
            return "同步电商订单";
        }
    }
    public interface WriteOffResultHistory {
        static String code() {
            return "writeOffResultHistory";
        }
        static String name() {
            return "应收回款核销履历";
        }
    }
    public interface CheckConfig {
        static String code() {
            return "checkConfig";
        }
        static String name() {
            return "对账策略配置";
        }
    }
    public interface ReceivableStatistics {
        static String code() {
            return "receivableStatistics";
        }
        static String name() {
            return "应收汇总";
        }
    }
    public interface JdSalesorder {
        static String code() {
            return "jdSalesorder";
        }
        static String name() {
            return "京东订单";
        }
    }
    public interface PddCheck {
        static String code() {
            return "pddCheck";
        }
        static String name() {
            return "拼多多账单";
        }
    }
    public interface KsSalesorder {
        static String code() {
            return "ksSalesorder";
        }
        static String name() {
            return "快手订单";
        }
    }
    public interface PlatformSubsidyInvoiceSettlement {
        static String code() {
            return "platformSubsidyInvoiceSettlement";
        }
        static String name() {
            return "平台补贴票结";
        }
    }
    public interface ExpenseInvoiceSettlement {
        static String code() {
            return "expenseInvoiceSettlement";
        }
        static String name() {
            return "费用项票结";
        }
    }
    public interface ReceivableCheckResult {
        static String code() {
            return "receivableCheckResult";
        }
        static String name() {
            return "应收对账";
        }
    }
    public interface ReceivableSalesOrder {
        static String code() {
            return "receivableSalesOrder";
        }
        static String name() {
            return "应收订单";
        }
    }
    public interface ReceivableCheckHistory {
        static String code() {
            return "receivableCheckHistory";
        }
        static String name() {
            return "应收对账履历";
        }
    }
    public interface HistoryVersion {
        static String code() {
            return "historyVersion";
        }
        static String name() {
            return "版本履历";
        }
    }
    public interface WriteOffResultSnapshot {
        static String code() {
            return "writeOffResultSnapshot";
        }
        static String name() {
            return "月度核销明细快照表";
        }
    }
    public interface TbSalesorder {
        static String code() {
            return "tbSalesorder";
        }
        static String name() {
            return "天猫订单";
        }
    }
    public interface CollectionOrder {
        static String code() {
            return "collectionOrder";
        }
        static String name() {
            return "收款单";
        }
    }
    public interface DyCheck {
        static String code() {
            return "dyCheck";
        }
        static String name() {
            return "抖音账单";
        }
    }
    public interface DySalesorder {
        static String code() {
            return "dySalesorder";
        }
        static String name() {
            return "抖音订单";
        }
    }
    public interface OmsSalesorder {
        static String code() {
            return "omsSalesorder";
        }
        static String name() {
            return "网店管家OMS订单";
        }
    }
    public interface SalesOrderCheckResult {
        static String code() {
            return "salesOrderCheckResult";
        }
        static String name() {
            return "订单对账";
        }
    }
    public interface JkyOmsOrder {
        static String code() {
            return "jkyOmsOrder";
        }
        static String name() {
            return "吉客云OMS订单";
        }
    }
    public interface CollectionSummary {
        static String code() {
            return "collectionSummary";
        }
        static String name() {
            return "收款汇总单";
        }
    }
    public interface JdCheck {
        static String code() {
            return "jdCheck";
        }
        static String name() {
            return "京东账单";
        }
    }
}
